Overview — dataspectra 0.0.1 documentation

# Overview

## How Dataspectra works

Traditionally, creating an interactive data visualization on the web requires obtaining 4 components. 1. Your data 2. An idea of how the web page looks. 3. Code to upload and access parts of the data quickly. 4. Code to plot the data using the specified parts of the data. 5. Code to arrange the plots and the text. 6. Uploading all of the above on a web server.

Dataspectra makes this process easier by including all of the code you need and uploading all of the information to Google Cloud Platform (Steps 3 to 6).

So to create a dataspectra page, you will first organize your data and specify how the web page and plots will look (Step 1). Then, create a google cloud account to let dataspectra know where to upload all of the code (step 2). And then, run dataspectra, which will take care of the rest.

## About the documentation

Sections 1. 2. and 3. will demonstrate how dataspectra works in a tutorial format.

To simply test whether dataspectra works, you can skip the latter half of Section 1 and use the included tutorial parameter file. You will need to still do Section 2 and Section 3.

Section 4 describes the full set of available parameters for full customization.

Section 5 provides information if you would like to help develop dataspectra further.

## Other perks of using dataspectra

- Easy Google Analytics set up.
- Easy Password setup.